@@ -8,6 +8,7 @@ from pydoctest.logging import log
 from pydoctest.parsers.parser import Parser
 from pydoctest.parsers.google_parser import GoogleParser
 from pydoctest.parsers.numpy_parser import NumpyParser
+from pydoctest.parsers.sphinx_parser import SphinxParser
 
 
 class Verbosity(IntEnum):
@@ -18,8 +19,8 @@ class Verbosity(IntEnum):
 
 PARSERS = {
     'google': GoogleParser,
-    # 'numpy': NumpyParser
-    # To be populated
+    'numpy': NumpyParser,
+    'sphinx': SphinxParser
 }
 
 
@@ -33,15 +34,21 @@ class Configuration():
         self.include_paths: List[str] = []
         self.exclude_paths: List[str] = []
 
-        # Throw an error if function does not have a docstring
-        self.fail_on_missing_docstring = False
-
         # Doctype parser to use, defaults to Google
         self.parser = "google"
 
         # Verbosity of reporter, currently only used by text-reporter
         self.verbosity = Verbosity.SHOW_FAILED
 
+        # Throw an error if function does not have a docstring
+        self.fail_on_missing_docstring = False
+
+        # Throw an error if function does not have a summary
+        self.fail_on_missing_summary = False
+
+        # Throw an error if 'raises' section does not list all exceptions
+        self.fail_on_raises_section = True
+
     @staticmethod
     def get_default_configuration(root_dir: Optional[str] = None) -> 'Configuration':
         """Returns a configuration with default values.
@@ -98,6 +105,9 @@ class Configuration():
     def get_parser(self) -> Parser:
         """Checks if the desired Parser exists and returns it.
 
+        Raises:
+            Exception: If parser from Configuration doesn't exist.
+
         Returns:
             Parser: A supported Parser.
         """
